% This function is part of the reproducible research addendum of the research manuscript:
% T. Necciari, B. Laback, S. Savel, S. Ystad, P. Balazs, S. Meunier, and R. Kronland-Martinet,
% "Auditory Time-Frequency Masking Function for Stimuli with Good Time-Frequency Localization"
%
% This function generates a 3-D plot of the time-frequency masking function in the time-ERB domain.
% The row experimental data are loaded and interpolated at the specified rates.
% 
% The following inputs are needed:
%   - ERBspac: sampling of the ERB axis (in ERB units)
%   - timespac: sampling of the time axis (in sec)
% 
% Optional input: range of the ERB axis provided as a scalar or vector.
%   - if scalar, the ERB axis ranges from [-val; +val]
%   - if vector, the ERB axis ranges from [valmin; valmax]
%   - if omitted, the range of measurements is used, that is [-4; +6 ERB units].
% 
% The function returns the generated time-frequency masking function in a matrix as well as a handle to the generated figure.
% 
% For example, Fig. 4 of the manuscript was generated using the command line
%   S1dataset_generateTFmaskfunc(1,.001,8);
% 
% Author: T. Necciari, 4.4.2016


function [dFi,dTi,AMi,fig_handle] = S1dataset_generateTFmaskfunc(ERBspac,timespac,varargin)

load S1dataset_rawdata.mat
% Provide the following variables
% dT: \Delta T in sec
% dF: \Delta F in ERB units
% data: Amount of masking in dB

% Do interpolation at the specified rates
if isempty(varargin)
%     No limits specified
    ERBmin = min(dF);
    ERBmax = max(dF);
elseif size(varargin) == 1
%     Some limits specified
    lim = varargin{1};
    if isscalar(lim)
%         A single value => mirror it around 0
        ERBmin = -lim;
        ERBmax = lim;
    else
        if size(lim,1)==2 || size(lim,2) == 2
            ERBmin = lim(1);
            ERBmax = lim(2);
        else
            error('More than two limits were provided!')
        end
    end
else
    error('Only one extra argument can be provided!');
end

dFi = ERBmin:ERBspac:ERBmax;
dTi = min(dT):timespac:max(dT);
AMi = interp2(dT,dF',data,dTi,dFi','linear',0);

fig_handle = figure;
mesh(dTi*1000,dFi,AMi)
xlabel('$\Delta T$ (ms)','interpreter','latex'),ylabel('$\Delta F$ (ERB units)','interpreter','latex'),zlabel('Amount of masking (dB)')
set(gca,'YDir','reverse')
title('Time-frequency masking function')
end
